@@ -1,7 +1,9 @@
 """
 A 2D trace object.
 """
-from typing import Mapping, Optional, Tuple, Union
+from __future__ import annotations
+
+from typing import Callable, Mapping, Optional, Sequence
 
 import numpy as np
 import pandas as pd
@@ -12,36 +14,59 @@ import dascore.proc
 from dascore.constants import DEFAULT_PATCH_ATTRS, PatchType
 from dascore.io import PatchIO
 from dascore.transform import TransformPatchNameSpace
+from dascore.utils.coords import Coords, assign_coords
 from dascore.utils.mapping import FrozenDict
-from dascore.utils.patch import Coords, _AttrsCoordsMixer
+from dascore.utils.patch import _AttrsCoordsMixer
 from dascore.viz import VizPatchNameSpace
 
 
 class Patch:
     """
-    A Class for storing and accessing 2D fiber data.
-    """
+    A Class for managing data and metadata.
 
-    # --- Dunder methods
+    Parameters
+    ----------
+    data
+        An array-like containing data, an xarray DataArray object, or a Patch.
+    coords
+        The coordinates, or dimensional labels for the data. These can be
+        passed in three forms:
+        {coord_name: data}
+        {coord_name: ((dimensions,), data)}
+        {coord_name: (dimensions, data)}
+    dims
+        A sequence of dimension strings. The first entry cooresponds to the
+        first axis of data, the second to the second dimension, and so on.
+    attrs
+        Optional attributes (non-coordinate metadata) passed as a dict.
+
+    Notes
+    -----
+    Unless data is a DataArray or Patch, data, coords, and dims are required.
+    """
 
     def __init__(
         self,
-        data: Union[ArrayLike, DataArray] = None,
-        coords: Mapping[str, ArrayLike] = None,
-        dims: Tuple[str] = None,
+        data: ArrayLike | DataArray | None = None,
+        coords: Mapping[str, ArrayLike] | None = None,
+        dims: Sequence[str] | None = None,
         attrs: Optional[Mapping] = None,
     ):
-        if isinstance(data, DataArray):
-            self._data_array = data
+        non_attrs = [x is None for x in [data, coords, dims]]
+        if isinstance(data, (DataArray, self.__class__)):
+            dar = data if isinstance(data, DataArray) else data._data_array
+            self._data_array = dar
             return
-        coords = {} if coords is None else coords
-        dims = dims if dims is not None else list(coords)
+        elif any(non_attrs) and not all(non_attrs):
+            msg = "data, coords, and dims must be defined to init Patch."
+            raise ValueError(msg)
         mixer = _AttrsCoordsMixer(attrs, coords, dims)
         attrs, coords = mixer()
         # get xarray coords from custom coords object
-        if isinstance(coords, Coords):
-            coords = coords._coords
-        self._data_array = DataArray(data=data, dims=dims, coords=coords, attrs=attrs)
+        xr_coords = coords.to_nested_dict()
+        self._data_array = DataArray(
+            data=data, dims=dims, coords=xr_coords, attrs=attrs
+        )
 
     def __eq__(self, other):
         """
@@ -109,9 +134,19 @@ class Patch:
             other = other.transpose(*self.dims)
         return np.equal(self.data, other.data).all()
 
-    def new(self: PatchType, data=None, coords=None, attrs=None) -> PatchType:
+    def new(
+        self: PatchType,
+        data: None | ArrayLike = None,
+        coords: None | dict[str | Sequence[str], ArrayLike] = None,
+        attrs: None | Mapping = None,
+        dims: None | Sequence[str] = None,
+    ) -> PatchType:
         """
-        Return a copy of the trace with data, coords, or attrs updated.
+        Return a copy of the Patch with updated data.
+
+        Parameters
+        ----------
+
         """
         data = data if data is not None else self.data
         attrs = attrs if attrs is not None else self.attrs
@@ -119,7 +154,7 @@ class Patch:
             coords = getattr(self.coords, "_coords", self.coords)
             dims = self.dims
         else:
-            dims = list(coords)
+            dims = dims or list(coords)
         return self.__class__(data=data, coords=coords, attrs=attrs, dims=dims)
 
     def update_attrs(self: PatchType, **attrs) -> PatchType:
@@ -144,12 +179,17 @@ class Patch:
 
     @property
     def coords(self):
-        """Return the data array."""
-        return Coords(self._data_array.coords)
+        """Return a dict of coordinate data {coord_name: data}"""
+        return Coords(self._data_array.coords, dims=self.dims).array_dict
 
     @property
-    def dims(self) -> Tuple[str, ...]:
-        """Return the data array."""
+    def coord_dims(self):
+        """Return a dict of coordinate dimensions {coord_name: (**dims)}"""
+        return Coords(self._data_array.coords, dims=self.dims).dims_dict
+
+    @property
+    def dims(self) -> tuple[str, ...]:
+        """Return the dimensions contained in patch."""
         return self._data_array.dims
 
     @property
@@ -157,6 +197,11 @@ class Patch:
         """Return the attributes of the trace."""
         return FrozenDict(self._data_array.attrs)
 
+    @property
+    def shape(self) -> tuple[int, ...]:
+        """Return the shape of the data array."""
+        return self._data_array.shape
+
     def to_xarray(self):
         """
         Return a data array with patch contents.
@@ -180,6 +225,7 @@ class Patch:
     resample = dascore.proc.resample
     iresample = dascore.proc.iresample
     interpolate = dascore.proc.interpolate
+    normalize = dascore.proc.normalize
 
     # --- Method Namespaces
     # Note: these can't be cached_property (from functools) or references
@@ -199,3 +245,26 @@ class Patch:
     def io(self) -> PatchIO:
         """Return a patch IO object for saving patches to various formats."""
         return PatchIO(self)
+
+    def pipe(self, func: Callable[["Patch", ...], "Patch"], *args, **kwargs) -> "Patch":
+        """
+        Pipe the patch to a function.
+
+        This is primarily useful for maintaining a chain of patch calls for
+        a function.
+
+        Parameters
+        ----------
+        func
+            The function to pipe the patch. It must take a patch instance as
+            the first argument followed by any number of positional or keyword
+            arguments, then return a patch.
+        *args
+            Positional arguments that get passed to func.
+        **kwargs
+            Keyword arguments passed to func.
+        """
+        return func(self, *args, **kwargs)
+
+    # Bind assign_coords as method
+    assign_coords = assign_coords
