@@ -46,7 +46,7 @@ class TimeDelta64(SimpleValidator):
 
 
 class PatchSummary(BaseModel):
-    """The expected minimum attributes for a Patch attrs."""
+    """The expected attributes for a Patch."""
 
     class Config:
         """Configuration for Patch Summary"""
@@ -65,6 +65,7 @@ class PatchSummary(BaseModel):
     distance_max: float = np.NaN
     d_distance: float = np.NaN
     instrument_id: str = ""
+    cable_id: str = ""
     dims: str = tuple()
     tag: str = ""
     station: str = ""
