@@ -15,7 +15,7 @@ from dascore.utils.chunk import ChunkManager
 from dascore.utils.docs import compose_docstring
 from dascore.utils.mapping import FrozenDict
 from dascore.utils.misc import CacheDescriptor
-from dascore.utils.patch import merge_patches, patches_to_df
+from dascore.utils.patch import _merge_patches, patches_to_df
 from dascore.utils.pd import (
     _convert_min_max_in_kwargs,
     adjust_segments,
@@ -170,7 +170,10 @@ class DataFrameSpool(BaseSpool):
             }
             out_list.append(patch.select(**select_kwargs))
         if len(out_list) > expected_len:
-            out_list = merge_patches(out_list)
+            patch_df = patches_to_df(out_list)
+            # Tolerance should be high since the dataframe chunker has
+            # already determined these rows should be merged together.
+            out_list = _merge_patches(patch_df, tolerance=1_000_000)
         return out_list
 
     @staticmethod
@@ -210,6 +213,8 @@ class DataFrameSpool(BaseSpool):
         self: SpoolType,
         overlap: Optional[Union[numeric_types, timeable_types]] = None,
         keep_partial: bool = False,
+        snap_coords: bool = True,
+        tolerance: float = 1.5,
         **kwargs,
     ) -> Self:
         """
@@ -220,6 +225,7 @@ class DataFrameSpool(BaseSpool):
             overlap=overlap,
             keep_partial=keep_partial,
             group_columns=self._group_columns,
+            tolerance=tolerance,
             **kwargs,
         )
         in_df, out_df = chunker.chunk(df)
