@@ -2,7 +2,7 @@
 Module to Patch Processing.
 """
 from .aggregate import aggregate
-from .basic import abs, rename, squeeze, transpose
+from .basic import abs, normalize, rename, squeeze, transpose
 from .detrend import detrend
 from .filter import pass_filter
 from .resample import decimate, interpolate, iresample, resample
