@@ -6,6 +6,7 @@ import copy
 import functools
 import inspect
 import re
+import warnings
 from fnmatch import translate
 from typing import (
     Any,
@@ -460,6 +461,7 @@ def patches_to_df(
         {fields}
     plus a field called 'patch' which contains a reference to each patch.
     """
+
     if isinstance(patches, dascore.BaseSpool):
         df = patches._df
     elif isinstance(patches, pd.DataFrame):
@@ -472,6 +474,11 @@ def patches_to_df(
         else:  # else populate with patches and concat history
             history = df["history"].apply(lambda x: ",".join(x))
             df = df.assign(patch=patches, history=history)
+    # Ensure history is in df
+    if "history" not in df.columns:
+        df = df.assign(history="")
+    if "patch" not in df.columns:
+        df["patch"] = [x for x in patches]
     return df
 
 
@@ -484,6 +491,39 @@ def merge_patches(
     """
     Merge all compatible patches in spool or patch list together.
 
+    Parameters
+    ----------
+    patches
+        A sequence of patches to merge (if compatible)
+    dim
+        The dimension along which to merge
+    check_history
+        If True, only merge patches with common history. This will, for
+        example, prevent merging filtered and unfiltered data together.
+    tolerance
+        The upper limit of a gap to tolerate in terms of the sampling
+        along the desired dimension. E.G., the default value means any patches
+        with gaps <= 1.5 * dt will be merged.
+    """
+    msg = (
+        "merge_patches is deprecated. Use spool.chunk instead."
+        "For example, to merge a list of patches you can use:"
+        "dascore.spool(patch_list).chunk(time=None) to merge on the time "
+        "dimension"
+    )
+    warnings.warn(msg, DeprecationWarning)
+    return _merge_patches(patches, dim, check_history, tolerance)
+
+
+def _merge_patches(
+    patches: Union[Sequence[PatchType], pd.DataFrame, SpoolType],
+    dim: str = "time",
+    check_history: bool = True,
+    tolerance: float = 1.5,
+) -> Sequence[PatchType]:
+    """
+    Merge all compatible patches in spool or patch list together.
+
     Parameters
     ----------
     patches
@@ -505,14 +545,14 @@ def merge_patches(
         sort_names = group_names + [min_name, max_name]
         if check_history:
             sort_names += ["history"]
-            patches = patches.assign(history=lambda x: x.get("history", "").apply(str))
+            patches = patches.assign(history=lambda x: x["history"].apply(str))
         return patches.sort_values(sort_names), sort_names, group_names
 
     def _merge_compatible_patches(patch_df):
         """perform merging after patch compatibility has been confirmed."""
         has_overlap = patch_df["_dist_to_previous"] <= to_timedelta64(0)
         overlap_start = patch_df[min_name] - patch_df["_dist_to_previous"]
-
+        # get data arrays
         dars = [x._data_array for x in patch_df["patch"]]
         dars = [
             _trim_or_fill(x, start) if needs_action else x
